@@ -24,29 +24,27 @@ runFTSdata <- function() {
                                                  "Period",
                                                  start = Sys.Date()-750,
                                                  end = Sys.Date()),
-
                                   br(),
                                   br(),
+                                  h4("Upper Graph", style = "text-align: left;"),
+                                  fluidRow(
+                                    column(6,
+                                  selectInput("dropdown3",
+                                              label = "Choose frequency",
+                                              choices = c("daily", "weekly", "monthly",
+                                                          "yearly"),
+                                              selected = "daily"),
+                                  textOutput("selected_option"),
                                   # p(actionButton("loadData", "Load", icon = icon("r-project")),
                                   #   br(),
                                   #   "Selected data is loaded into global R-environment.",
                                   #   style = "font-family: 'consolas'; font-si16pt"),
-                                  # br(),
-                                  # br(),
-                                  p(downloadButton("downloadData", "Save", icon = icon("floppy-disk")),
-                                    br(),
-                                    "Save selected data on local hard drive.",
-                                    style = "font-family: 'consolas'; font-si16pt"),
-                                  br(),
-                                  br(),
-                                  p(actionButton("closeApp", "Close", icon = icon("power-off")),
-                                    br(),
-                                    "Close Application.",
-                                    style = "font-family: 'consolas'; font-si16pt"),
-                                  br(),
-                                  br(),
+                                  #br(),
+                                  #br(),
+                                    ),
+                                  column(6,
                                   selectInput("dropdown",
-                                              label = "Choose FTS - Upper Graph",
+                                              label = "Choose FTS",
                                               choices = c("no FTS selected", "price_open", "price_close",
                                                           "price_adjusted",
                                                           "price_high", "price_low",
@@ -57,8 +55,21 @@ runFTSdata <- function() {
                                   textOutput("selected_option"),
                                   br(),
                                   br(),
+                                    )
+                                  ),
+                                  h4("Lower Graph", style = "text-align: left;"),
+                                  fluidRow(
+                                    column(6,
+                                  selectInput("dropdown4",
+                                              label = "Choose frequency",
+                                              choices = c("daily", "weekly", "monthly",
+                                                          "yearly"),
+                                              selected = "daily"),
+                                  textOutput("selected_option"),
+                                    ),
+                                  column(6,
                                   selectInput("dropdown2",
-                                              label = "Choose FTS - Lower Graph",
+                                              label = "Choose FTS",
                                               choices = c("no FTS selected", "price_open", "price_close",
                                                           "price_adjusted",
                                                           "price_high", "price_low",
@@ -67,9 +78,21 @@ runFTSdata <- function() {
                                                           "cumret_adjusted_prices"),
                                               selected = "ret_closing_prices"),
                                   textOutput("selected_option"),
-                                  br()
+                                  br(),
+                                  br(),
+                                    )
+                                  ),
+                                  p(downloadButton("downloadData", "Save", icon = icon("floppy-disk")),
+                                    br(),
+                                    "Save selected data on local hard drive",
+                                    style = "font-family: 'consolas'; font-si16pt"),
+                                  br(),
+                                  br(),
+                                  p(actionButton("closeApp", "Close", icon = icon("power-off")),
+                                    br(),
+                                    "Close Application",
+                                    style = "font-family: 'consolas'; font-si16pt"),
                                 ),
-
                                 mainPanel(br(),
                                           br(),
                                           conditionalPanel(
@@ -89,35 +112,52 @@ runFTSdata <- function() {
     updateSelectizeInput(session, "ticker",
                          choices = c(paste0(ticker_stocks$Ticker[-1], " (", ticker_stocks$Name[-1], ")"),
                                      paste0(ticker_indices$Ticker, " (", ticker_indices$Name, ")")),
-                         selected = '',
+                         selected = '^GDAXI (DAX)',
                          server = TRUE)
 
     dataInput <- reactive({
       req(input$ticker)
       req(input$Date[1])
       req(input$Date[2])
+      req(input$dropdown3)
       ticker = strsplit(input$ticker, " ")[[1]][1]
       suppressWarnings(
         suppressMessages(
           yfR::yf_get(tickers = ticker, first_date = input$Date[1],
-                      last_date = input$Date[2], freq_data = "daily",
+                      last_date = input$Date[2], freq_data = input$dropdown3,
                       cache_folder = file.path(tempdir(), 'BGS_Cache'))
         )
       )
     })
 
+    dataInput2 <- reactive({
+      req(input$ticker)
+      req(input$Date[1])
+      req(input$Date[2])
+      req(input$dropdown4)
+      ticker = strsplit(input$ticker, " ")[[1]][1]
+      suppressWarnings(
+        suppressMessages(
+          yfR::yf_get(tickers = ticker, first_date = input$Date[1],
+                      last_date = input$Date[2], freq_data = input$dropdown4,
+                      cache_folder = file.path(tempdir(), 'BGS_Cache'))
+        )
+      )
+    })
 
   output$plot1 <- renderDygraph({
     req(input$ticker)
     req(input$Date[1])
     req(input$Date[2])
     req(input$dropdown)
+    req(input$dropdown3)
     req(dataInput())
     dat = dataInput()
     plot_data = xts::xts(dat[paste(input$dropdown)], dat$ref_date)
-    dygraphs::dygraph(plot_data, main = paste(input$ticker, input$dropdown, "(daily)"),
+    dygraphs::dygraph(plot_data, main = paste(input$ticker, input$dropdown, input$dropdown3),
                       #ylab = "X<sub>t</sub>",
-                      group = "FZS") %>%
+                      group = "FZS1") %>%
+      dygraphs::dyRangeSelector(height = 20) %>%
       dygraphs::dyUnzoom()
   })
 
@@ -127,13 +167,15 @@ runFTSdata <- function() {
       req(input$Date[1])
       req(input$Date[2])
       req(input$dropdown)
-      req(dataInput())
+      req(input$dropdown4)
+      req(dataInput2())
 
-      dat2 = dataInput()#[-1, ]
+      dat2 = dataInput2()#[-1, ]
       plot_data2 = xts::xts(dat2[paste(input$dropdown2)], dat2$ref_date)
-      dygraphs::dygraph(plot_data2, main = paste(input$ticker, input$dropdown2, "(daily)"),
+      dygraphs::dygraph(plot_data2, main = paste(input$ticker, input$dropdown2, input$dropdown4),
                         #ylab = "Y<sub>t</sub>",
-                        xlab = "Daily observations (t)", group = "FZS") %>%
+                        #xlab = "Daily observations (t)",
+                        group = "FZS2") %>%
         dygraphs::dyRangeSelector(height = 20) %>%
         dygraphs::dyUnzoom()
     })
